Struct sktablelayout::CellProperties [−][src]
pub struct CellProperties {
pub size: SizeGrouping,
pub flags: CellFlags,
pub colspan: u8,
pub callback: Option<Box<PositioningFn>>,
}Encapsulates all properties for a cell; contributes to eventual layout decisions.
Fields
size: SizeGrouping
Controls the desired sizes for this cell.
flags: CellFlags
Controls various binary flags for the cell.
colspan: u8
Controls how many columns this cell will occupy.
callback: Option<Box<PositioningFn>>
Applies positioning updates for this cell. Note that this
value always becomes None when cloned, so you cannot set
default callbacks for cell policies.
Methods
impl CellProperties[src]
impl CellPropertiespub fn new() -> Self[src]
pub fn new() -> Selfpub fn with_defaults(layout: &TableLayout) -> Self[src]
pub fn with_defaults(layout: &TableLayout) -> SelfInherits the default settings as determined by a
TableLayout. Will first try to match the defaults for the
column this would be added to, then the row, then the fallback
defaults. Note that these defaults apply only if the cell
was added next and if the defaults have not been changed
since. The correct use of with_defaults is to initialize
CellProperties for immediate insertion to a layout.
pub fn minimum_size(self, minimum: Size) -> Self[src]
pub fn minimum_size(self, minimum: Size) -> Selfpub fn maximum_size(self, maximum: Size) -> Self[src]
pub fn maximum_size(self, maximum: Size) -> Selfpub fn preferred_size(self, preferred: Size) -> Self[src]
pub fn preferred_size(self, preferred: Size) -> Selfpub fn expand(self) -> Self[src]
pub fn expand(self) -> Selfpub fn expand_horizontal(self) -> Self[src]
pub fn expand_horizontal(self) -> Selfpub fn expand_vertical(self) -> Self[src]
pub fn expand_vertical(self) -> Selfpub fn fill(self) -> Self[src]
pub fn fill(self) -> Selfpub fn fill_horizontal(self) -> Self[src]
pub fn fill_horizontal(self) -> Selfpub fn fill_vertical(self) -> Self[src]
pub fn fill_vertical(self) -> Selfpub fn anchor_top(self) -> Self[src]
pub fn anchor_top(self) -> Selfpub fn anchor_bottom(self) -> Self[src]
pub fn anchor_bottom(self) -> Selfpub fn anchor_left(self) -> Self[src]
pub fn anchor_left(self) -> Selfpub fn anchor_right(self) -> Self[src]
pub fn anchor_right(self) -> Selfpub fn anchor_center(self) -> Self[src]
pub fn anchor_center(self) -> Selfpub fn anchor_horizontal_center(self) -> Self[src]
pub fn anchor_horizontal_center(self) -> Selfpub fn anchor_vertical_center(self) -> Self[src]
pub fn anchor_vertical_center(self) -> Selfpub fn uniform(self) -> Self[src]
pub fn uniform(self) -> Selfpub fn colspan(self, span: u8) -> Self[src]
pub fn colspan(self, span: u8) -> Selfpub fn callback(self, fun: Box<PositioningFn>) -> Self[src]
pub fn callback(self, fun: Box<PositioningFn>) -> SelfTrait Implementations
impl Default for CellProperties[src]
impl Default for CellPropertiesimpl Clone for CellProperties[src]
impl Clone for CellPropertiesAuto Trait Implementations
impl !Send for CellProperties
impl !Send for CellPropertiesimpl !Sync for CellProperties
impl !Sync for CellProperties