Struct sktablelayout::Size [−][src]
Individual size constraint for a cell.
Fields
width: f32
height: f32
Methods
impl Size[src]
impl Sizepub fn join_max(a: &Size, b: &Size) -> Self[src]
pub fn join_max(a: &Size, b: &Size) -> Selfpub fn join_min(a: &Size, b: &Size) -> Self[src]
pub fn join_min(a: &Size, b: &Size) -> Selfpub fn spread(&self, divisions: f32) -> Self[src]
pub fn spread(&self, divisions: f32) -> SelfDivides the width and height by a givin division level. Used when a size must be spread across multiple table cells.
pub fn within(&self, other: &Size) -> bool[src]
pub fn within(&self, other: &Size) -> boolReturns whether this size should fit within another size.